@@ -40,7 +40,7 @@
 #include "config.h"
 #endif
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "gdict-context.h"
 #include "gdict-enum-types.h"
