@@ -31,6 +31,7 @@
 
 #include <string.h>
 #include <signal.h>
+#include <stdlib.h>
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -93,6 +94,16 @@ quit_application (GSearchWindow * gsearch)
 	gtk_main_quit ();
 }
 
+void
+version_cb (const gchar * option_name,
+            const gchar * value,
+            gpointer data,
+            GError ** error)
+{
+        g_print ("%s %s\n", g_get_application_name (), VERSION);
+        exit (0);
+}
+
 void
 quit_session_cb (EggSMClient * client,
                  gpointer data)
@@ -796,7 +807,7 @@ move_to_trash_cb (GtkAction * action,
 		GtkTreeIter iter;
 		GList * list;
 		GFile * g_file;
-		GError * error;
+		GError * error = NULL;
 		gchar * utf8_basename;
 		gchar * utf8_filename;
 		gchar * locale_filename;
@@ -851,7 +862,7 @@ move_to_trash_cb (GtkAction * action,
 
 			if (response == GTK_RESPONSE_OK) {
 				GFile * g_file_tmp;
-				GError * error_tmp;
+				GError * error_tmp = NULL;
 
 				g_file_tmp = g_file_new_for_path (locale_filename);
 				result = g_file_delete (g_file_tmp, NULL, &error_tmp);
